@@ -213,7 +213,7 @@ impl Mul for Point {
 }
 
 /// Alignment options
-#[derive(Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
+#[derive(Debug, Clone, Copy, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub enum Align {
     /// Alling by minimal value
     Min,
@@ -432,7 +432,7 @@ impl Mul<Transform> for Transform {
 }
 
 /// Bounding box with sides directed along the axes
-#[derive(Clone, Copy)]
+#[derive(Clone, Copy, PartialEq)]
 pub struct BBox {
     /// Point with minimal x and y values
     min: Point,
